@@ -4,10 +4,13 @@
 import time
 import board
 import displayio
-from adafruit_progressbar import ProgressBar
+from adafruit_progressbar.horizontalprogressbar import (
+    HorizontalProgressBar,
+    HorizontalFillDirection,
+)
 
 # Make the display context
-splash = displayio.Group(max_size=10)
+splash = displayio.Group()
 board.DISPLAY.show(splash)
 
 # set progress bar width and height relative to board's display
@@ -18,18 +21,20 @@ x = board.DISPLAY.width // 2 - width // 2
 y = board.DISPLAY.height // 3
 
 # Create a new progress_bar object at (x, y)
-progress_bar = ProgressBar(x, y, width, height, 1.0)
+progress_bar = HorizontalProgressBar(
+    (x, y), (width, height), direction=HorizontalFillDirection.LEFT_TO_RIGHT
+)
 
 # Append progress_bar to the splash group
 splash.append(progress_bar)
 
-current_progress = 0.0
+current_value = progress_bar.minimum
 while True:
     # range end is exclusive so we need to use 1 bigger than max number that we want
-    for current_progress in range(0, 101, 1):
-        print("Progress: {}%".format(current_progress))
-        progress_bar.progress = current_progress / 100  # convert to decimal
+    for current_value in range(progress_bar.minimum, progress_bar.maximum + 1, 1):
+        print("Progress: {}%".format(current_value))
+        progress_bar.value = current_value
         time.sleep(0.01)
     time.sleep(0.3)
-    progress_bar.progress = 0.0
+    progress_bar.value = progress_bar.minimum
     time.sleep(0.3)
